@@ -272,7 +272,6 @@ OC.L10N.register(
     "Select conversation" : "Seleccioneu una conversa",
     "on" : "a",
     "at" : "a",
-    "Reminder" : "Recordatori",
     "before at" : "abans a les",
     "Notification" : "Notificació",
     "Email" : "Correu",
@@ -283,7 +282,6 @@ OC.L10N.register(
     "Edit time" : "Modifica l'hora",
     "Save time" : "Desar l'hora",
     "Remove reminder" : "Suprimeix el recordatori",
-    "+ Add reminder" : "+ Afegeix un recordatori",
     "Add reminder" : "Afegeix un recordatori",
     "seconds" : "segons",
     "minutes" : "minuts",
@@ -318,26 +316,25 @@ OC.L10N.register(
     "Awaiting response" : "Esperant resposta",
     "Checking availability" : "Consultant disponibilitat",
     "Has not responded to {organizerName}'s invitation yet" : "Encara no ha respost a la invitació de {organizerName}",
-    "Select automatic slot" : "Selecció d’interval automàtica",
     "chairperson" : "responsable",
     "required participant" : "participant obligatori",
     "non-participant" : "no participant",
     "optional participant" : "participant opcional",
     "{organizer} (organizer)" : "{organizer} (organitzador)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Disponible",
-    "Busy (tentative)" : "Ocupat (provisional)",
-    "Busy" : "Ocupat",
-    "Out of office" : "Fora de l'oficina",
-    "Unknown" : "Desconegut",
     "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
-    "with" : "amb",
-    "Available times:" : "Horaris disponibles:",
     "Suggestion accepted" : "S'ha acceptat el suggeriment",
+    "Legend" : "Llegenda",
+    "Out of office" : "Fora de l'oficina",
+    "Attendees:" : "Assistents:",
     "Done" : "Fet",
     "Search room" : "Cerca sala",
     "Room name" : "Nom de la sala",
     "Check room availability" : "Consulta la disponibilitat de l'habitació",
+    "Free" : "Disponible",
+    "Busy (tentative)" : "Ocupat (provisional)",
+    "Busy" : "Ocupat",
+    "Unknown" : "Desconegut",
     "Find a time" : "Troba un moment",
     "The invitation has been accepted successfully." : "La invitació s'ha acceptat correctament.",
     "Failed to accept the invitation." : "No s'ha pogut acceptar la invitació.",
@@ -376,7 +373,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No es pot modificar la configuració de tot el dia per als esdeveniments que formen part d'un conjunt de recurrència.",
     "From" : "De",
     "To" : "A",
-    "All day" : "Tot el dia",
     "Repeat" : "Repeteix",
     "_time_::_times_" : ["vegada","vegades"],
     "never" : "mai",
@@ -400,7 +396,7 @@ OC.L10N.register(
     "Does not repeat" : "No es repeteix",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definició de recurrència d'aquest esdeveniment no és del tot compatible amb Nextcloud. Si canvieu les opcions de recurrència, es poden perdre certes recurrències.",
     "No rooms or resources yet" : "Encara no hi ha sales ni recursos",
-    "Suggestions" : "Suggeriments",
+    "Resources" : "Recursos",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seient","{seatingCapacity} seients"],
     "Add resource" : "Afegeix un recurs",
     "Has a projector" : "Té un projector",
@@ -467,16 +463,16 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detecció automàtica de la zona horària va determinar que la vostra zona horària fos UTC.\nÉs probable que això sigui el resultat de les mesures de seguretat del vostre navegador web.\nSi us plau, configureu la vostra zona horària manualment a la configuració del calendari.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No s'ha trobat la vostra zona horària configurada ({timezoneId}). Tornant a l'UTC.\nCanvieu la vostra zona horària a la configuració i informeu d'aquest problema.",
     "Availability of {displayName}" : "Disponibilitat de {displayName}",
+    "Edit event" : "Edita l'esdeveniment",
     "Event does not exist" : "L'esdeveniment no existeix",
     "Duplicate" : "Duplica",
     "Delete this occurrence" : "Suprimeix aquesta ocurrència",
     "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
+    "All day" : "Tot el dia",
     "Modifications wont get propagated to the organizer and other attendees" : "Les modificacions no es propagaran a l'organitzador i als altres assistents",
-    "Details" : "Detalls",
     "Managing shared access" : "Gestió de l'accés compartit",
     "Deny access" : "Denega l'accés",
     "Invite" : "Convida",
-    "Resources" : "Recursos",
     "_User requires access to your file_::_Users require access to your file_" : ["L'usuari requereix accés al vostre fitxer","Els usuaris requereixen accés al vostre fitxer"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["El fitxer adjunt requereix accés compartit","Els fitxers adjunts requereixen accés compartit"],
     "Untitled event" : "Esdeveniment sense títol",
@@ -582,6 +578,13 @@ OC.L10N.register(
     "This is an event reminder." : "Això és un recordatori de l'esdeveniment.",
     "Error while parsing a PROPFIND error" : "S'ha produït un error en analitzar un error PROPFIND",
     "Appointment not found" : "No s'ha trobat la cita",
-    "User not found" : "No s'ha trobat l'usuari"
+    "User not found" : "No s'ha trobat l'usuari",
+    "Reminder" : "Recordatori",
+    "+ Add reminder" : "+ Afegeix un recordatori",
+    "Select automatic slot" : "Selecció d’interval automàtica",
+    "with" : "amb",
+    "Available times:" : "Horaris disponibles:",
+    "Suggestions" : "Suggeriments",
+    "Details" : "Detalls"
 },
 "nplurals=2; plural=(n != 1);");
