@@ -272,7 +272,6 @@ OC.L10N.register(
     "Select conversation" : "Vælg samtale",
     "on" : "på",
     "at" : "ved",
-    "Reminder" : "Påmindelse",
     "before at" : "før kl",
     "Notification" : "Notifikation",
     "Email" : "E-mail",
@@ -283,7 +282,6 @@ OC.L10N.register(
     "Edit time" : "Rediger tid",
     "Save time" : "Gem tid",
     "Remove reminder" : "Fjern påmindelse",
-    "+ Add reminder" : "+ Tilføj påmindelse",
     "Add reminder" : "Tilføj påmindelse",
     "seconds" : "sekunder ",
     "minutes" : "minutter",
@@ -318,26 +316,25 @@ OC.L10N.register(
     "Awaiting response" : "Afventer svar",
     "Checking availability" : "Kontrol af tilgængelighed",
     "Has not responded to {organizerName}'s invitation yet" : "Har endnu ikke svaret på {organizerName}s invitation",
-    "Select automatic slot" : "Vælg automatisk tidspunkt",
     "chairperson" : "formand",
     "required participant" : "nødvendig deltager",
     "non-participant" : "ikke-deltager",
     "optional participant" : "valgfri deltager",
     "{organizer} (organizer)" : "{organizer} (arrangør)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Ledig",
-    "Busy (tentative)" : "Optaget (foreløbig)",
-    "Busy" : "Optaget",
-    "Out of office" : "Ikke på kontoret",
-    "Unknown" : "Ukendt",
     "Availability of attendees, resources and rooms" : "Tilgængelighed af deltagere, ressourcer og lokaler",
-    "with" : "med",
-    "Available times:" : "Tilgængelige tidspunkter",
     "Suggestion accepted" : "Forslag accepteret",
+    "Legend" : "Forklaring",
+    "Out of office" : "Ikke på kontoret",
+    "Attendees:" : "Deltagere:",
     "Done" : "Færdig",
     "Search room" : "Søg rum",
     "Room name" : "Rumnavn",
     "Check room availability" : "kontroller rumtilgængelighed",
+    "Free" : "Ledig",
+    "Busy (tentative)" : "Optaget (foreløbig)",
+    "Busy" : "Optaget",
+    "Unknown" : "Ukendt",
     "Find a time" : "Find et tidspunkt",
     "The invitation has been accepted successfully." : "Invitationen er blevet accepteret.",
     "Failed to accept the invitation." : "Kunne ikke acceptere invitationen.",
@@ -376,7 +373,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan ikke ændre heldagsindstillingen for begivenheder, der er en del af et gentagelsessæt.",
     "From" : "Fra",
     "To" : "Til",
-    "All day" : "Hele dagen",
     "Repeat" : "Gentag",
     "_time_::_times_" : ["gang","gange"],
     "never" : "aldrig",
@@ -400,7 +396,7 @@ OC.L10N.register(
     "Does not repeat" : "Gentager sig ikke",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gentagelsesdefinitionen af denne begivenhed understøttes ikke fuldt ud af Nextcloud. Hvis du redigerer gentagelsesmulighederne, kan visse gentagelser gå tabt.",
     "No rooms or resources yet" : "Ingen lokaler eller ressourcer endnu",
-    "Suggestions" : "Forslag",
+    "Resources" : "Resourcer",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sæde","{seatingCapacity} sæder"],
     "Add resource" : "Tilføj ressource",
     "Has a projector" : "Har en projektor",
@@ -467,16 +463,16 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiske tidszoneregistrering bestemte, at din tidszone var UTC.\nDette er højst sandsynligt resultatet af sikkerhedsforanstaltninger i din webbrowser.\nIndstil venligst din tidszone manuelt i kalenderindstillingerne.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerede tidszone ({timezoneId}) blev ikke fundet. Falder tilbage til UTC.\nSkift venligst din tidszone i indstillingerne og rapporter dette problem.",
     "Availability of {displayName}" : "Tilgængelighed af {displayName}",
+    "Edit event" : "Rediger begivenhed",
     "Event does not exist" : "Begivenheden eksisterer ikke",
     "Duplicate" : "dubletter",
     "Delete this occurrence" : "Slet denne forekomst",
     "Delete this and all future" : "Slet denne og alle fremtidige",
+    "All day" : "Hele dagen",
     "Modifications wont get propagated to the organizer and other attendees" : "Ændringer vil ikke blive bredt ud til organisatoren og andre deltagere",
-    "Details" : "Detaljer",
     "Managing shared access" : "Håndtering af delt adgang",
     "Deny access" : "Nægt adgang",
     "Invite" : "Invitere",
-    "Resources" : "Resourcer",
     "_User requires access to your file_::_Users require access to your file_" : ["Brugeren kræver adgang til din fil","Brugere kræver adgang til din fil"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Vedhæftet fil kræver delt adgang","Vedhæftede filer, der kræver delt adgang"],
     "Untitled event" : "Unavngiven begivenhed",
@@ -582,6 +578,13 @@ OC.L10N.register(
     "This is an event reminder." : "Dette er en begivenhedspåmindelse.",
     "Error while parsing a PROPFIND error" : "Fejl under parsing af en PROPFIND-fejl",
     "Appointment not found" : "Aftale ikke fundet",
-    "User not found" : "Bruger ikke fundet"
+    "User not found" : "Bruger ikke fundet",
+    "Reminder" : "Påmindelse",
+    "+ Add reminder" : "+ Tilføj påmindelse",
+    "Select automatic slot" : "Vælg automatisk tidspunkt",
+    "with" : "med",
+    "Available times:" : "Tilgængelige tidspunkter",
+    "Suggestions" : "Forslag",
+    "Details" : "Detaljer"
 },
 "nplurals=2; plural=(n != 1);");
