@@ -241,7 +241,6 @@ OC.L10N.register(
     "Select conversation" : "مکالمه را انتخاب کنید",
     "on" : "بر",
     "at" : "در",
-    "Reminder" : "Reminder",
     "before at" : "قبل از در",
     "Notification" : "اطلاع",
     "Email" : "ایمیل",
@@ -252,7 +251,6 @@ OC.L10N.register(
     "Edit time" : "ویرایش زمان",
     "Save time" : "صرفه جویی در وقت",
     "Remove reminder" : "یادآوری را حذف کنید",
-    "+ Add reminder" : "+ اضافه کردن یادآوری",
     "Add reminder" : "Add reminder",
     "seconds" : "ثانیه ها",
     "minutes" : "دقیقه",
@@ -281,14 +279,16 @@ OC.L10N.register(
     "Checking availability" : "Checking availability",
     "Has not responded to {organizerName}'s invitation yet" : "Has not responded to {organizerName}'s invitation yet",
     "{organizer} (organizer)" : "{organizer} (organizer)",
+    "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
+    "Legend" : "Legend",
+    "Out of office" : "بیرون از دفتر",
+    "Attendees:" : "شرکت‌کنندگان:",
+    "Done" : "Done",
+    "Room name" : "Room name",
     "Free" : "آزاد",
     "Busy (tentative)" : "مشغول (آزمایشی)",
     "Busy" : "مشغول",
-    "Out of office" : "بیرون از دفتر",
     "Unknown" : "نامشخص",
-    "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
-    "Done" : "Done",
-    "Room name" : "Room name",
     "The invitation has been accepted successfully." : "The invitation has been accepted successfully.",
     "Failed to accept the invitation." : "Failed to accept the invitation.",
     "The invitation has been declined successfully." : "The invitation has been declined successfully.",
@@ -318,7 +318,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Cannot modify all-day setting for events that are part of a recurrence-set.",
     "From" : "از",
     "To" : "به",
-    "All day" : "تمام روز",
     "Repeat" : "تکرار",
     "_time_::_times_" : ["بار","بارها"],
     "never" : "هرگز",
@@ -341,7 +340,7 @@ OC.L10N.register(
     "Does not repeat" : "تکرار نمی کند",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "تعریف بازگشتی از این رویداد توسط نکست کلود کاملاً پشتیبانی نمی شود. اگر گزینه های بازگشتی را ویرایش کنید ، ممکن است بازگشتی های خاصی از بین بروند.",
     "No rooms or resources yet" : "No rooms or resources yet",
-    "Suggestions" : "Suggestions",
+    "Resources" : "منابع",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seat","{seatingCapacity} seats"],
     "Add resource" : "Add resource",
     "Has a projector" : "Has a projector",
@@ -396,15 +395,15 @@ OC.L10N.register(
     "Personal" : "شخصی",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
+    "Edit event" : "ویرایش رویداد",
     "Event does not exist" : "رویداد وجود ندارد",
     "Duplicate" : "Duplicate",
     "Delete this occurrence" : "این رخداد را حذف کنید",
     "Delete this and all future" : "این و همه آینده را حذف کنید",
-    "Details" : "جزئیات",
+    "All day" : "تمام روز",
     "Managing shared access" : "Managing shared access",
     "Deny access" : "Deny access",
     "Invite" : "Invite",
-    "Resources" : "منابع",
     "_User requires access to your file_::_Users require access to your file_" : ["User requires access to your file","Users require access to your file"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
     "Untitled event" : "رویداد بدون عنوان",
@@ -498,6 +497,10 @@ OC.L10N.register(
     "Imported {filename}" : "وارد شده {نام پرونده}",
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
-    "User not found" : "کاربر یافت نشد"
+    "User not found" : "کاربر یافت نشد",
+    "Reminder" : "Reminder",
+    "+ Add reminder" : "+ اضافه کردن یادآوری",
+    "Suggestions" : "Suggestions",
+    "Details" : "جزئیات"
 },
 "nplurals=2; plural=(n > 1);");
