@@ -257,7 +257,6 @@ OC.L10N.register(
     "Select conversation" : "Valitse keskustelu",
     "on" : "päivä",
     "at" : "kellonaika",
-    "Reminder" : "Muistutus",
     "before at" : "ennen",
     "Notification" : "Ilmoitus",
     "Email" : "Sähköposti",
@@ -268,7 +267,6 @@ OC.L10N.register(
     "Edit time" : "Muokkaa aikaa",
     "Save time" : "Tallenna aika",
     "Remove reminder" : "Poista muistutus",
-    "+ Add reminder" : "+ Lisää muistutus",
     "Add reminder" : "Lisää muistutus",
     "seconds" : "sekuntia",
     "minutes" : "minuuttia",
@@ -308,19 +306,19 @@ OC.L10N.register(
     "optional participant" : "valinnainen osallistuja",
     "{organizer} (organizer)" : "{organizer} (järjestäjä)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Vapaa",
-    "Busy (tentative)" : "Varattu (alustava)",
-    "Busy" : "Varattu",
-    "Out of office" : "Ulkona toimistolta",
-    "Unknown" : "Tuntematon",
     "Availability of attendees, resources and rooms" : "Osallistujien, resurssien ja huoneiden saatavuus",
-    "with" : "kanssa",
-    "Available times:" : "Saatavilla olevat ajat:",
     "Suggestion accepted" : "Ehdotus hyväksytty",
+    "Legend" : "Selite",
+    "Out of office" : "Ulkona toimistolta",
+    "Attendees:" : "Osallistujat:",
     "Done" : "Valmis",
     "Search room" : "Etsi huonetta",
     "Room name" : "Huoneen nimi",
     "Check room availability" : "Tarkista huoneen saatavuus",
+    "Free" : "Vapaa",
+    "Busy (tentative)" : "Varattu (alustava)",
+    "Busy" : "Varattu",
+    "Unknown" : "Tuntematon",
     "Find a time" : "Löydä aika",
     "The invitation has been accepted successfully." : "Kutsu on hyväksytty.",
     "Failed to accept the invitation." : "Kutsun hyväksyminen epäonnistui.",
@@ -353,7 +351,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Koko päivän tapahtumia, jotka ovat osa toistuvaa tapahtumaa, ei voida muokata.",
     "From" : "Lähettäjä",
     "To" : "Vastaanottaja",
-    "All day" : "Koko päivä",
     "Repeat" : "Toista",
     "_time_::_times_" : ["kerran","kertaa"],
     "never" : "ei koskaan",
@@ -377,7 +374,7 @@ OC.L10N.register(
     "Does not repeat" : "Ei toistu",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Tapahtuman toistuvuusasetus ei ole Nextcloudin tukema. Jos muokkaat toistuvuusasetusta, jotkin toistuvista tapahtumista saattavat kadota.",
     "No rooms or resources yet" : "Ei huoneita tai resursseja vielä",
-    "Suggestions" : "Ehdotukset",
+    "Resources" : "Resurssit",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} istumapaikka","{seatingCapacity} istumapaikkaa"],
     "Add resource" : "Lisää resurssi",
     "Has a projector" : "On projektori",
@@ -438,14 +435,14 @@ OC.L10N.register(
     "Personal" : "Henkilökohtainen",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automaattinen aikavyöhykkeentunnistus määritti aikavyöhykkeesi olevan UTC. \nTämä johtuu todennäköisesti selaimesi tietoturva-asetuksista.\nOle hyvä ja aseta aikavyöhykkeesi manuaalisesti kalenterin asetuksista.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Asettamaasi aikavyöhykettä ({timezoneId}) ei löytynyt. Vaihdetaan takaisin UTC:hen.\nOle hyvä ja vaihda aikavyöhykkeesi asetuksista ja ilmoita tästä ongelmasta.",
+    "Edit event" : "Muokkaa tapahtumaa",
     "Event does not exist" : "Tapahtumaa ei ole olemassa",
     "Delete this occurrence" : "Poista tämä esiintymä",
     "Delete this and all future" : "Poista tämä ja kaikki tulevat",
-    "Details" : "Tiedot",
+    "All day" : "Koko päivä",
     "Managing shared access" : "Jaetun pääsyn hallinta",
     "Deny access" : "Estä pääsy",
     "Invite" : "Kutsu",
-    "Resources" : "Resurssit",
     "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
     "Untitled event" : "Nimetön tapahtuma",
     "Close" : "Sulje",
@@ -538,6 +535,7 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Tämän tapahtuman erikoisväri. Ylittää kalenterin väriarvon.",
     "Error while sharing file" : "Virhe tiedostoa jakaessa",
     "Error while sharing file with user" : "Virhe tiedostoa jakaessa käyttäjän kanssa",
+    "Error creating a folder {folder}" : "Virhe luotaessa kansiota {folder}",
     "Attachment {fileName} already exists!" : "Liite {fileName} on jo olemassa!",
     "An error occurred during getting file information" : "Tiedostojen tietoja noutaessa tapahtui virhe",
     "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
@@ -545,6 +543,12 @@ OC.L10N.register(
     "Imported {filename}" : "Tuotiin {filename}",
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
-    "User not found" : "Käyttäjää ei löydy"
+    "User not found" : "Käyttäjää ei löydy",
+    "Reminder" : "Muistutus",
+    "+ Add reminder" : "+ Lisää muistutus",
+    "with" : "kanssa",
+    "Available times:" : "Saatavilla olevat ajat:",
+    "Suggestions" : "Ehdotukset",
+    "Details" : "Tiedot"
 },
 "nplurals=2; plural=(n != 1);");
