@@ -257,7 +257,6 @@ OC.L10N.register(
     "Select conversation" : "会話を選択",
     "on" : "曜日",
     "at" : "で",
-    "Reminder" : "リマインダー",
     "before at" : "次の時間分早めに通知",
     "Notification" : "通知",
     "Email" : "メール",
@@ -268,7 +267,6 @@ OC.L10N.register(
     "Edit time" : "時刻を変更",
     "Save time" : "時刻を保存",
     "Remove reminder" : "リマインダーを削除",
-    "+ Add reminder" : "+ リマインダーを追加",
     "Add reminder" : "リマインダーを追加",
     "seconds" : "秒",
     "minutes" : "分",
@@ -299,26 +297,24 @@ OC.L10N.register(
     "Awaiting response" : "返答待ち",
     "Checking availability" : "空き状況の確認",
     "Has not responded to {organizerName}'s invitation yet" : "{organizerName} の招待にまだ応答していません",
-    "Select automatic slot" : "自動スロット選択",
     "chairperson" : "主宰者",
     "required participant" : "参加必須",
     "non-participant" : "非参加",
     "optional participant" : "任意参加",
     "{organizer} (organizer)" : "{organizer} (organizer)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "空き",
-    "Busy (tentative)" : "ビジー (暫定)",
-    "Busy" : "ビジー",
-    "Out of office" : "オフィス外",
-    "Unknown" : "不明",
     "Availability of attendees, resources and rooms" : "出席者、リソース、ルームの空き状況",
-    "with" : "とともに",
-    "Available times:" : "利用可能な時間帯:",
     "Suggestion accepted" : "提案を受け入れた",
+    "Out of office" : "オフィス外",
+    "Attendees:" : "参加者:",
     "Done" : "完了",
     "Search room" : "ルームを検索する",
     "Room name" : "会議室名",
     "Check room availability" : "ルームの空き状況を確認する",
+    "Free" : "空き",
+    "Busy (tentative)" : "ビジー (暫定)",
+    "Busy" : "ビジー",
+    "Unknown" : "不明",
     "Find a time" : "時間を見つける",
     "The invitation has been accepted successfully." : "招待状は正常に受理されました。",
     "Failed to accept the invitation." : "招待を受け入れることに失敗しました。",
@@ -354,7 +350,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定は変更できません。",
     "From" : "開始",
     "To" : "宛先",
-    "All day" : "終日",
     "Repeat" : "繰り返し",
     "_time_::_times_" : ["回数"],
     "never" : "なし",
@@ -377,7 +372,7 @@ OC.L10N.register(
     "Does not repeat" : "繰り返さない",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "このイベントの繰り返し定義は、Nextcloudでは完全にサポートされていません。繰り返しオプションを編集すると、特定の繰り返しが失われる場合があります。",
     "No rooms or resources yet" : "ルームやリソースがありません",
-    "Suggestions" : "提案",
+    "Resources" : "リソース",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} 席"],
     "Add resource" : "リソースを追加する",
     "Has a projector" : "プロジェクタ設置",
@@ -443,15 +438,15 @@ OC.L10N.register(
     "Personal" : "個人",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動的なタイムゾーンの検出により、あなたのタイムゾーンはUTCと判断されました。\nこれはおそらく、あなたのウェブブラウザのセキュリティ対策の結果です。\nカレンダーの設定でタイムゾーンを手動で設定してください。",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "設定されたタイムゾーン ({timezoneId}) が見つかりませんでした。UTCにフォールバックします。\n設定でタイムゾーンを変更して、この問題を報告してください。",
+    "Edit event" : "イベントを編集",
     "Event does not exist" : "イベントは存在しません",
     "Duplicate" : "複製",
     "Delete this occurrence" : "この出来事を削除",
     "Delete this and all future" : "これ以降を削除する",
-    "Details" : "詳細",
+    "All day" : "終日",
     "Managing shared access" : "共有アクセスの管理",
     "Deny access" : "アクセスを拒否する",
     "Invite" : "招待状",
-    "Resources" : "リソース",
     "_User requires access to your file_::_Users require access to your file_" : ["ファイルへのアクセスが必要なユーザ"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["添付ファイルには共有アクセスが必要です"],
     "Untitled event" : "無題のイベント",
@@ -547,6 +542,13 @@ OC.L10N.register(
     "Imported {filename}" : "インポートされた {filename}",
     "This is an event reminder." : "これはイベントのリマインダーです。",
     "Appointment not found" : "予定が見つかりません",
-    "User not found" : "ユーザーが見つかりません"
+    "User not found" : "ユーザーが見つかりません",
+    "Reminder" : "リマインダー",
+    "+ Add reminder" : "+ リマインダーを追加",
+    "Select automatic slot" : "自動スロット選択",
+    "with" : "とともに",
+    "Available times:" : "利用可能な時間帯:",
+    "Suggestions" : "提案",
+    "Details" : "詳細"
 },
 "nplurals=1; plural=0;");
