@@ -211,7 +211,6 @@ OC.L10N.register(
     "Create a new conversation" : "Sukurti naują pokalbį",
     "on" : "šiomis dienomis",
     "at" : ",",
-    "Reminder" : "Priminimas",
     "before at" : "prieš įvykį, ties",
     "Notification" : "Pranešimas",
     "Email" : "Elektroninis laiškas",
@@ -222,7 +221,6 @@ OC.L10N.register(
     "Edit time" : "Taisyti laiką",
     "Save time" : "Įrašyti laiką",
     "Remove reminder" : "Šalinti priminimą",
-    "+ Add reminder" : "+ Pridėti priminimą",
     "Add reminder" : "Pridėti priminimą",
     "seconds" : "sekundes",
     "minutes" : "minučių",
@@ -241,15 +239,15 @@ OC.L10N.register(
     "chairperson" : "pirmininkas",
     "{organizer} (organizer)" : "{organizer} (organizatorius)",
     "{attendee} ({role})" : "{attendee} ({role})",
+    "Availability of attendees, resources and rooms" : "Kviestinių, išteklių ir kambarių prieinamumas",
+    "Out of office" : "Ne darbo vietoje",
+    "Attendees:" : "Kviestiniai:",
+    "Done" : "Atlikta",
+    "Room name" : "Kambario pavadinimas",
     "Free" : "Laisvas laikas",
     "Busy (tentative)" : "Užimtas laikas (preliminariai)",
     "Busy" : "Užimtas laikas",
-    "Out of office" : "Ne darbo vietoje",
     "Unknown" : "Nežinoma",
-    "Availability of attendees, resources and rooms" : "Kviestinių, išteklių ir kambarių prieinamumas",
-    "Available times:" : "Prieinami laikai:",
-    "Done" : "Atlikta",
-    "Room name" : "Kambario pavadinimas",
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
     "Tentative" : "Preliminarus",
@@ -272,7 +270,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Negalima modifikuoti „Visos dienos“ nustatymą įvykiams, kurie yra pasikartojimo rinkinio dalis.",
     "From" : "Nuo",
     "To" : "Kam",
-    "All day" : "Visą dieną",
     "Repeat" : "Kartoti",
     "_time_::_times_" : ["karto","kartų","kartų","karto"],
     "never" : "niekada",
@@ -295,7 +292,7 @@ OC.L10N.register(
     "Does not repeat" : "Nekartojamas",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud nepalaiko pilnai šio įvykio pasikartojimo apibrėžimo. Jei taisysite pasikartojimo parinktis, tam tikri pasikartojimai gali būti prarasti.",
     "No rooms or resources yet" : "Kol kas nėra kambarių ar išteklių",
-    "Suggestions" : "Pasiūlymai",
+    "Resources" : "Ištekliai",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sėdima vieta","{seatingCapacity} sėdimos vietos","{seatingCapacity} sėdimų vietų","{seatingCapacity} sėdima vieta"],
     "Add resource" : "Pridėti išteklių",
     "Has a projector" : "Yra projektorius",
@@ -337,11 +334,11 @@ OC.L10N.register(
     "Personal" : "Asmeniniai",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatinis laiko juostos aptikimas nustatė, kad jūsų laiko juosta yra UTC.\nTaip, greičiausiai, yra dėl jūsų saityno naršyklės saugos priemonių.\nKalendoriaus nustatymuose prašome rankiniu būdu nusistatyti laiko juostą.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Jūsų konfigūruota laiko juosta ({timezoneId}) nerasta. Grįžtama į UTC.\nPrašome nustatymuose pakeisti savo laiko juostą ir pranešti apie šią problemą.",
+    "Edit event" : "Taisyti įvykį",
     "Event does not exist" : "Įvykio nėra",
     "Delete this occurrence" : "Ištrinti šį pasikartojimą",
     "Delete this and all future" : "Ištrinti šį ir visus būsimus",
-    "Details" : "Išsamiau",
-    "Resources" : "Ištekliai",
+    "All day" : "Visą dieną",
     "Untitled event" : "Įvykis be pavadinimo",
     "Close" : "Užverti",
     "Subscribe to {name}" : "Prenumeruoti {name}",
@@ -433,6 +430,11 @@ OC.L10N.register(
     "Imported {filename}" : "Importuotas {filename}",
     "This is an event reminder." : "Tai priminimas apie įvykį.",
     "Appointment not found" : "Susitikimas nerastas",
-    "User not found" : "Naudotojas nerastas"
+    "User not found" : "Naudotojas nerastas",
+    "Reminder" : "Priminimas",
+    "+ Add reminder" : "+ Pridėti priminimą",
+    "Available times:" : "Prieinami laikai:",
+    "Suggestions" : "Pasiūlymai",
+    "Details" : "Išsamiau"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
