@@ -255,7 +255,6 @@ OC.L10N.register(
     "Select conversation" : "Velg samtale",
     "on" : "på",
     "at" : "ved",
-    "Reminder" : "Påminnelse",
     "before at" : "før ved",
     "Notification" : "Varsel",
     "Email" : "E-post",
@@ -266,7 +265,6 @@ OC.L10N.register(
     "Edit time" : "Rediger tidspunkt",
     "Save time" : "Lagre tidspunkt",
     "Remove reminder" : "Fjern påminnelse",
-    "+ Add reminder" : "+ Legg til påminnelse",
     "Add reminder" : "Legg til påminnelse",
     "seconds" : "sekund",
     "minutes" : "minutter",
@@ -297,26 +295,25 @@ OC.L10N.register(
     "Awaiting response" : "Venter på svar",
     "Checking availability" : "Sjekker ledighet",
     "Has not responded to {organizerName}'s invitation yet" : "Har ikke svart på {organizerName} sin invitasjon ennå",
-    "Select automatic slot" : "Velg automatisk luke",
     "chairperson" : "ordstyrer",
     "required participant" : "påkrevd deltaker",
     "non-participant" : "ikke-deltaker",
     "optional participant" : "valgfri deltaker",
     "{organizer} (organizer)" : "{organizer} (organisator)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Ledig",
-    "Busy (tentative)" : "Opptatt (foreløpig)",
-    "Busy" : "Opptatt",
-    "Out of office" : "Fraværende",
-    "Unknown" : "Ukjent",
     "Availability of attendees, resources and rooms" : "Ledighet til deltagere, ressurser og rom",
-    "with" : "med",
-    "Available times:" : "Tilgjengelige tidspunkter:",
     "Suggestion accepted" : "Forslag akseptert",
+    "Legend" : "Legende",
+    "Out of office" : "Fraværende",
+    "Attendees:" : "Deltakere:",
     "Done" : "Ferdig",
     "Search room" : "Søk rom",
     "Room name" : "Romnavn",
     "Check room availability" : "Sjekk rom tilgjengelighet",
+    "Free" : "Ledig",
+    "Busy (tentative)" : "Opptatt (foreløpig)",
+    "Busy" : "Opptatt",
+    "Unknown" : "Ukjent",
     "Find a time" : "Finn et tidspunkt",
     "The invitation has been accepted successfully." : "Invitasjonen er godtatt.",
     "Failed to accept the invitation." : "Kunne ikke godta invitasjonen.",
@@ -353,7 +350,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan ikke endre \"hel dag\"-innstillingen for hendelser som er en del av et gjentakelsessett.",
     "From" : "Fra",
     "To" : "Til",
-    "All day" : "Hele dagen",
     "Repeat" : "Gjenta",
     "_time_::_times_" : ["gang","ganger"],
     "never" : "aldri",
@@ -376,7 +372,7 @@ OC.L10N.register(
     "Does not repeat" : "Gjentas ikke",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gjentakelsesregelen av denne hendelsen støttes ikke fullt ut av Nextcloud. Hvis du redigerer gjentakelsesalternativene, kan visse gjentakelser gå tapt.",
     "No rooms or resources yet" : "Ingen rom eller ressurser enda",
-    "Suggestions" : "Forslag",
+    "Resources" : "Ressurser",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sete","{seatingCapacity} seter"],
     "Add resource" : "Legg til ressurs",
     "Has a projector" : "Har en projektor",
@@ -442,15 +438,15 @@ OC.L10N.register(
     "Personal" : "Personlig",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiske tidssonegjenkjenningen bestemte at tidssonen din var UTC.\nDette er mest sannsynlig et resultat av sikkerhetstiltak i nettleseren din.\nVennligst still inn tidssonen manuelt i kalenderinnstillingene.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerte tidssone ({timezoneId}) ble ikke funnet. Faller tilbake til UTC.\nVennligst endre tidssonen din i innstillingene og rapporter dette problemet.",
+    "Edit event" : "Rediger hendelse",
     "Event does not exist" : "Hendelsen finnes ikke",
     "Duplicate" : "Duplikat",
     "Delete this occurrence" : "Slett denne hendelsen",
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
-    "Details" : "Detaljer",
+    "All day" : "Hele dagen",
     "Managing shared access" : "Administrere delt tilgang",
     "Deny access" : "Nekte adgang",
     "Invite" : "Invitere",
-    "Resources" : "Ressurser",
     "_User requires access to your file_::_Users require access to your file_" : ["Bruker må ha tilgang til filen din","Brukere må ha tilgang til filen din"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Vedlegg som krever delt tilgang","Vedlegg som krever delt tilgang"],
     "Untitled event" : "Hendelse uten tittel",
@@ -539,6 +535,7 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Spesial farge for denne hendelsen. Overstyrer kalenderfargen.",
     "Error while sharing file" : "Feil under deling av fil",
     "Error while sharing file with user" : "Feil under deling av fil med bruker",
+    "Error creating a folder {folder}" : "Feil ved opprettelse av mappen {mappe}",
     "Attachment {fileName} already exists!" : "Vedlegget {fileName} eksisterer allerede!",
     "An error occurred during getting file information" : "Det oppsto en feil under henting av filinformasjon",
     "An error occurred, unable to delete the calendar." : "En feil oppsto, kan ikke slette kalenderen. ",
@@ -546,6 +543,13 @@ OC.L10N.register(
     "This is an event reminder." : "Dette er en hendelsespåminnelse.",
     "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
     "Appointment not found" : "Avtale ikke funnet",
-    "User not found" : "Fant ikke brukeren"
+    "User not found" : "Fant ikke brukeren",
+    "Reminder" : "Påminnelse",
+    "+ Add reminder" : "+ Legg til påminnelse",
+    "Select automatic slot" : "Velg automatisk luke",
+    "with" : "med",
+    "Available times:" : "Tilgjengelige tidspunkter:",
+    "Suggestions" : "Forslag",
+    "Details" : "Detaljer"
 },
 "nplurals=2; plural=(n != 1);");
