@@ -262,7 +262,6 @@ OC.L10N.register(
     "Select conversation" : "Selecteer een gesprek",
     "on" : "op",
     "at" : "om",
-    "Reminder" : "Herinnering",
     "before at" : "ervoor om",
     "Notification" : "Melding",
     "Email" : "Email",
@@ -273,7 +272,6 @@ OC.L10N.register(
     "Edit time" : "Bewerk tijd",
     "Save time" : "Bewaar tijd",
     "Remove reminder" : "Verwijder herinnering",
-    "+ Add reminder" : "+ Toevoegen herinnering",
     "Add reminder" : "Voeg herinnering toe",
     "seconds" : "seconden",
     "minutes" : "minuten",
@@ -304,26 +302,25 @@ OC.L10N.register(
     "Awaiting response" : "Wachten op antwoord",
     "Checking availability" : "Beschikbaarheid controleren",
     "Has not responded to {organizerName}'s invitation yet" : "Er is nog niet gereageerd op de uitnodiging van {organizerName}.",
-    "Select automatic slot" : "Selecteer automatisch tijdsblok",
     "chairperson" : "voorzitter",
     "required participant" : "vereiste deelnemer",
     "non-participant" : "geen-deelnemer",
     "optional participant" : "optionele deelnemer",
     "{organizer} (organizer)" : "{organizer} (organizer)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Vrij",
-    "Busy (tentative)" : "Bezig (voorlopig)",
-    "Busy" : "Bezet",
-    "Out of office" : "Niet op kantoor",
-    "Unknown" : "Onbekend",
     "Availability of attendees, resources and rooms" : "Beschikbaarheid van aanwezigen, objecten en ruimtes",
-    "with" : "met",
-    "Available times:" : "Beschikbare tijden:",
     "Suggestion accepted" : "Voorstel geaccepteerd",
+    "Legend" : "Legenda",
+    "Out of office" : "Niet op kantoor",
+    "Attendees:" : "Deelnemers:",
     "Done" : "Klaar",
     "Search room" : "Zoek ruimte",
     "Room name" : "Kamernaam",
     "Check room availability" : "Beschikbaarheid ruimtes controleren",
+    "Free" : "Vrij",
+    "Busy (tentative)" : "Bezig (voorlopig)",
+    "Busy" : "Bezet",
+    "Unknown" : "Onbekend",
     "Find a time" : "Vind een tijdstip",
     "The invitation has been accepted successfully." : "De uitnodiging is succesvol geaccepteerd.",
     "Failed to accept the invitation." : "Aanemen van uitnodiging is mislukt",
@@ -360,7 +357,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Het lukt niet om de gehele-dag instelling aan te passen voor afspraken die onderdeel zijn van een herhaalde-set.",
     "From" : "Van",
     "To" : "Naar",
-    "All day" : "Hele dag",
     "Repeat" : "Herhaling",
     "_time_::_times_" : ["keer","keer"],
     "never" : "geen",
@@ -383,7 +379,7 @@ OC.L10N.register(
     "Does not repeat" : "Niet herhalen",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "De herhaal instelling van deze afspraak wordt niet volledig ondersteund door Nextcloud. Als je de herhaal instellingen wijzigt, gaan bepaalde herhalingen mogelijk verloren.",
     "No rooms or resources yet" : "Nog geen kamers of bronnen",
-    "Suggestions" : "Suggesties",
+    "Resources" : "Bronnen",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} plaats","{seatingCapacity} plaatsen"],
     "Add resource" : "Voeg resource toe",
     "Has a projector" : "Heeft een projector",
@@ -449,15 +445,15 @@ OC.L10N.register(
     "Personal" : "Persoonlijk",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "De automatisch gedetecteerde tijdzone is UTC.\nDit komt waarschijnlijk door beveiligingsmaatregelen van je webbrowser. Stel de tijdzone handmatig in bij de agenda-instellingen.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Je ingestelde tijdzone ({timezoneId}) werd niet gevonden. Er wordt teruggevallen op UTC.\nWijzig je tijdzone in instellingen en meld het incident.",
+    "Edit event" : "Bewerk gebeurtenis",
     "Event does not exist" : "Activiteit bestaat niet",
     "Duplicate" : "Duplicaat",
     "Delete this occurrence" : "Verwijder deze afspraak",
     "Delete this and all future" : "Verwijder deze en toekomstige",
-    "Details" : "Details",
+    "All day" : "Hele dag",
     "Managing shared access" : "Beheren van gedeelde toegang",
     "Deny access" : "Weiger toegang",
     "Invite" : "Uitnodigen",
-    "Resources" : "Bronnen",
     "_User requires access to your file_::_Users require access to your file_" : ["Gebruikers hebben toegang nodig tot uw bestand","Gebruikers hebben toegang nodig tot uw bestand"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bijlagen die gedeelde toegang vereisen","Bijlagen die gedeelde toegang vereisen"],
     "Untitled event" : "Afspraken zonder naam",
@@ -552,6 +548,13 @@ OC.L10N.register(
     "Imported {filename}" : "Geïmporteerd {filename}",
     "This is an event reminder." : "Dit is een herinnering aan een evenement.",
     "Appointment not found" : "Afspraak niet gevonden",
-    "User not found" : "Gebruiker niet gevonden"
+    "User not found" : "Gebruiker niet gevonden",
+    "Reminder" : "Herinnering",
+    "+ Add reminder" : "+ Toevoegen herinnering",
+    "Select automatic slot" : "Selecteer automatisch tijdsblok",
+    "with" : "met",
+    "Available times:" : "Beschikbare tijden:",
+    "Suggestions" : "Suggesties",
+    "Details" : "Details"
 },
 "nplurals=2; plural=(n != 1);");
